@@ -1,14 +1,14 @@
 package t::lib::Test;
 
 use strict;
-use Exporter   ();
-use ORLite     ();
-use Test::More ();
+use Exporter      ();
+use ORLite::Array ();
+use Test::More    ();
 use File::Spec::Functions ':ALL';
 
 use vars qw{$VERSION @ISA @EXPORT};
 BEGIN {
-	$VERSION = '0.01';
+	$VERSION = '0.02';
 	@ISA     = 'Exporter';
 	@EXPORT  = qw{ test_db connect_ok create_ok };
 }
